---
title: '[공지] 2024.08.17 네이버페이 결제 장애 '
category: 공지사항
tags:
  - 공지사항
datetime: 2024-08-17T09:57:59.786Z
---

안녕하세요, 포트원 고객지원팀입니다.

네이버페이 내부적으로 오류가 발생된 것으로 전달받아 안내해 드립니다.

현재 조치 완료되었으며, 상세 내용은 아래 참고 부탁드립니다. 참고 부탁드립니다.

감사합니다.

---

- 관련 서비스 : 신용카드, 체크카드
- 장애원인 : 네이버 IDC 장애
- 장애 발생 시각 : 2024년 08월 17일  17시31분 \~ 19시 경
